==> it%2B%2B3.8.0.tar.gz: it++3.8.0/src/base/itpp_version.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2003 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*!
  \file
  \brief Implementation of IT++ version function
  \author Tony Ottosson

  1.3

  2003/05/22 08:55:19
*/

#include "base/itpp_version.h"

namespace itpp { 

  string itpp_version(void)
  {
    string release_tag = "release-3-8-0";
    string out;
    int pos;
  
    if (release_tag == "release-3-8-0")
      return "CVS version";
    
    pos = release_tag.find_first_of("-");
    out = release_tag.substr(pos+1, release_tag.size());
  
    // Replace all remaining "-" with "."
    pos = out.find("-");
    while (pos != -1)
      {
	out.replace(pos, 1, ".");
	pos = out.find("-");
      }
  
    return out;
  }

} //namespace itpp

==> it%2B%2B3.8.1.tar.gz: it++3.8.1/src/base/itpp_version.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2005 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*!
  \file
  \brief Implementation of IT++ version function
  \author Tony Ottosson

  1.4

  2005/06/13 08:37:17
*/

#include "base/itpp_version.h"

namespace itpp { 

  std::string itpp_version(void)
  {
    std::string release_tag = "release-3-8-1";
    std::string out;
    int pos;
  
    if (release_tag == "release-3-8-1")
      return "CVS version";
    
    pos = release_tag.find_first_of("-");
    out = release_tag.substr(pos+1, release_tag.size());
  
    // Replace all remaining "-" with "."
    pos = out.find("-");
    while (pos != -1)
      {
	out.replace(pos, 1, ".");
	pos = out.find("-");
      }
  
    return out;
  }

} //namespace itpp
